Installation
============

**bluetooth_mesh** requires Python >= 3.6

Installing/upgrading from PyPI
----------------------------------------

To install the latest version from PyPI:

::

   $ pip install --upgrade bluetooth_mesh

There are a number of extra features available, with additional dependencies:

* documentation

::

   $ pip install bluetooth_mesh[docs]

* command line tools (e.g. `meshcli`)

::

   $ pip install bluetooth_mesh[tools]

